@@ -39,8 +39,6 @@
 #include "dbushelper.h"
 #include "daemon.h"
 
-static const QString TRUSTED_DEVICES = QStringLiteral("trusted_devices_ssl");
-
 struct KdeConnectConfigPrivate {
 
     // The Initializer object sets things up, and also does cleanup when it goes out of scope
@@ -51,6 +49,7 @@ struct KdeConnectConfigPrivate {
     QSslCertificate certificate; // Use QSslCertificate instead of QCA::Certificate due to compatibility with QSslSocket
 
     QSettings* config;
+    QSettings* trusted_devices;
 
 };
 
@@ -65,6 +64,7 @@ KdeConnectConfig::KdeConnectConfig()
 {
     //qCDebug(KDECONNECT_CORE) << "QCA supported capabilities:" << QCA::supportedFeatures().join(",");
     if(!QCA::isSupported("rsa")) {
+        qCritical() << "Could not find support for RSA in your QCA installation";
         Daemon::instance()->reportError(
                              i18n("KDE Connect failed to start"),
                              i18n("Could not find support for RSA in your QCA installation. If your "
@@ -77,18 +77,17 @@ KdeConnectConfig::KdeConnectConfig()
     QDir().mkpath(baseConfigDir().path());
 
     //.config/kdeconnect/config
-    d->config = new QSettings(baseConfigDir().absoluteFilePath("config"), QSettings::IniFormat);
+    d->config = new QSettings(baseConfigDir().absoluteFilePath(QStringLiteral("config")), QSettings::IniFormat);
+    d->trusted_devices = new QSettings(baseConfigDir().absoluteFilePath(QStringLiteral("trusted_devices")), QSettings::IniFormat);
 
     //Register my own id if not there yet
-    d->config->beginGroup("myself");
-    if (!d->config->contains("id")) {
+    if (!d->config->contains(QStringLiteral("id"))) {
         QString uuid = QUuid::createUuid().toString();
         DbusHelper::filterNonExportableCharacters(uuid);
-        d->config->setValue("id", uuid);
+        d->config->setValue(QStringLiteral("id"), uuid);
         d->config->sync();
         qCDebug(KDECONNECT_CORE) << "My id:" << uuid;
     }
-    d->config->endGroup();
 
     const QFile::Permissions strict = QFile::ReadOwner | QFile::WriteOwner | QFile::ReadUser | QFile::WriteUser;
 
@@ -103,7 +102,7 @@ KdeConnectConfig::KdeConnectConfig()
         d->privateKey = QCA::KeyGenerator().createRSA(2048);
 
         if (!privKey.open(QIODevice::ReadWrite | QIODevice::Truncate))  {
-            Daemon::instance()->reportError(QLatin1String("KDE Connect"), i18n("Could not store private key file: %1", keyPath));
+            Daemon::instance()->reportError(QStringLiteral("KDE Connect"), i18n("Could not store private key file: %1", keyPath));
         } else {
             privKey.setPermissions(strict);
             privKey.write(d->privateKey.toPEM().toLatin1());
@@ -127,8 +126,8 @@ KdeConnectConfig::KdeConnectConfig()
         QDateTime endTime = startTime.addYears(10);
         QCA::CertificateInfo certificateInfo;
         certificateInfo.insert(QCA::CommonName,deviceId());
-        certificateInfo.insert(QCA::Organization,"KDE");
-        certificateInfo.insert(QCA::OrganizationalUnit,"Kde connect");
+        certificateInfo.insert(QCA::Organization,QStringLiteral("KDE"));
+        certificateInfo.insert(QCA::OrganizationalUnit,QStringLiteral("Kde connect"));
         certificateOptions.setInfo(certificateInfo);
         certificateOptions.setFormat(QCA::PKCS10);
         certificateOptions.setSerialNumber(QCA::BigInteger(10));
@@ -137,7 +136,7 @@ KdeConnectConfig::KdeConnectConfig()
         d->certificate = QSslCertificate(QCA::Certificate(certificateOptions, d->privateKey).toPEM().toLatin1());
 
         if (!cert.open(QIODevice::ReadWrite | QIODevice::Truncate))  {
-            Daemon::instance()->reportError(QLatin1String("KDE Connect"), i18n("Could not store certificate file: %1", certPath));
+            Daemon::instance()->reportError(QStringLiteral("KDE Connect"), i18n("Could not store certificate file: %1", certPath));
         } else {
             cert.setPermissions(strict);
             cert.write(d->certificate.toPem());
@@ -153,36 +152,30 @@ KdeConnectConfig::KdeConnectConfig()
 QString KdeConnectConfig::name()
 {
     QString defaultName = qgetenv("USER") + '@' + QHostInfo::localHostName();
-    d->config->beginGroup("myself");
-    QString name = d->config->value("name", defaultName).toString();
-    d->config->endGroup();
+    QString name = d->config->value(QStringLiteral("name"), defaultName).toString();
     return name;
 }
 
-void KdeConnectConfig::setName(QString name)
+void KdeConnectConfig::setName(const QString& name)
 {
-    d->config->beginGroup("myself");
-    d->config->setValue("name", name);
-    d->config->endGroup();
+    d->config->setValue(QStringLiteral("name"), name);
     d->config->sync();
 }
 
 QString KdeConnectConfig::deviceType()
 {
-    return "desktop"; // TODO
+    return QStringLiteral("desktop"); // TODO
 }
 
 QString KdeConnectConfig::deviceId()
 {
-    d->config->beginGroup("myself");
-    QString id = d->config->value("id", "").toString();
-    d->config->endGroup();
+    QString id = d->config->value(QStringLiteral("id"), "").toString();
     return id;
 }
 
 QString KdeConnectConfig::privateKeyPath()
 {
-    return baseConfigDir().absoluteFilePath("privateKey.pem");
+    return baseConfigDir().absoluteFilePath(QStringLiteral("privateKey.pem"));
 }
 
 QCA::PrivateKey KdeConnectConfig::privateKey()
@@ -197,7 +190,7 @@ QCA::PublicKey KdeConnectConfig::publicKey()
 
 QString KdeConnectConfig::certificatePath()
 {
-    return baseConfigDir().absoluteFilePath("certificate.pem");
+    return baseConfigDir().absoluteFilePath(QStringLiteral("certificate.pem"));
 }
 
 QSslCertificate KdeConnectConfig::certificate()
@@ -208,76 +201,62 @@ QSslCertificate KdeConnectConfig::certificate()
 QDir KdeConnectConfig::baseConfigDir()
 {
     QString configPath = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation);
-    QString kdeconnectConfigPath = QDir(configPath).absoluteFilePath("kdeconnect");
+    QString kdeconnectConfigPath = QDir(configPath).absoluteFilePath(QStringLiteral("kdeconnect"));
     return QDir(kdeconnectConfigPath);
 }
 
 QStringList KdeConnectConfig::trustedDevices()
 {
-    d->config->beginGroup(TRUSTED_DEVICES);
-    const QStringList& list = d->config->childGroups();
-    d->config->endGroup();
+    const QStringList& list = d->trusted_devices->childGroups();
     return list;
 }
 
 
 void KdeConnectConfig::addTrustedDevice(const QString &id, const QString &name, const QString &type)
 {
-    d->config->beginGroup(TRUSTED_DEVICES);
-    d->config->beginGroup(id);
-    d->config->setValue("name", name);
-    d->config->setValue("type", type);
-    d->config->endGroup();
-    d->config->endGroup();
-    d->config->sync();
+    d->trusted_devices->beginGroup(id);
+    d->trusted_devices->setValue(QStringLiteral("name"), name);
+    d->trusted_devices->setValue(QStringLiteral("type"), type);
+    d->trusted_devices->endGroup();
+    d->trusted_devices->sync();
 
     QDir().mkpath(deviceConfigDir(id).path());
 }
 
 KdeConnectConfig::DeviceInfo KdeConnectConfig::getTrustedDevice(const QString &id)
 {
-    d->config->beginGroup(TRUSTED_DEVICES);
-    d->config->beginGroup(id);
+    d->trusted_devices->beginGroup(id);
 
     KdeConnectConfig::DeviceInfo info;
-    info.deviceName = d->config->value("name", QLatin1String("unnamed")).toString();
-    info.deviceType = d->config->value("type", QLatin1String("unknown")).toString();
+    info.deviceName = d->trusted_devices->value(QStringLiteral("name"), QLatin1String("unnamed")).toString();
+    info.deviceType = d->trusted_devices->value(QStringLiteral("type"), QLatin1String("unknown")).toString();
 
-    d->config->endGroup();
-    d->config->endGroup();
+    d->trusted_devices->endGroup();
     return info;
 }
 
 void KdeConnectConfig::removeTrustedDevice(const QString &deviceId)
 {
-    d->config->beginGroup(TRUSTED_DEVICES);
-    d->config->beginGroup(deviceId);
-    d->config->remove(QString());
-    d->config->endGroup();
-    d->config->endGroup();
-    d->config->sync();
+    d->trusted_devices->remove(deviceId);
+    d->trusted_devices->sync();
     //We do not remove the config files.
 }
 
 // Utility functions to set and get a value
-void KdeConnectConfig::setDeviceProperty(QString deviceId, QString key, QString value)
+void KdeConnectConfig::setDeviceProperty(const QString& deviceId, const QString& key, const QString& value)
 {
-    d->config->beginGroup(TRUSTED_DEVICES);
-    d->config->beginGroup(deviceId);
-    d->config->setValue(key, value);
-    d->config->endGroup();
-    d->config->endGroup();
-    d->config->sync();
+    d->trusted_devices->beginGroup(deviceId);
+    d->trusted_devices->setValue(key, value);
+    d->trusted_devices->endGroup();
+    d->trusted_devices->sync();
 }
 
-QString KdeConnectConfig::getDeviceProperty(QString deviceId, QString key, QString defaultValue)
+QString KdeConnectConfig::getDeviceProperty(const QString& deviceId, const QString& key, const QString& defaultValue)
 {
     QString value;
-    d->config->beginGroup(TRUSTED_DEVICES);
-    d->config->beginGroup(deviceId);
-    value = d->config->value(key, defaultValue).toString();
-    d->config->endGroup();
-    d->config->endGroup();
+    d->trusted_devices->beginGroup(deviceId);
+    value = d->trusted_devices->value(key, defaultValue).toString();
+    d->trusted_devices->endGroup();
     return value;
 }
 
