@@ -37,17 +37,17 @@ Mounter::Mounter(SftpPlugin* sftp)
     , m_started(false)
 {
 
-    connect(m_sftp, SIGNAL(packageReceived(NetworkPackage)), this, SLOT(onPakcageReceived(NetworkPackage)));
+    connect(m_sftp, &SftpPlugin::packageReceived, this, &Mounter::onPakcageReceived);
 
-    connect(&m_connectTimer, SIGNAL(timeout()), this, SLOT(onMountTimeout()));
+    connect(&m_connectTimer, &QTimer::timeout, this, &Mounter::onMountTimeout);
 
-    connect(this, SIGNAL(mounted()), &m_connectTimer, SLOT(stop()));
-    connect(this, SIGNAL(failed(QString)), &m_connectTimer, SLOT(stop()));
+    connect(this, &Mounter::mounted, &m_connectTimer, &QTimer::stop);
+    connect(this, &Mounter::failed, &m_connectTimer, &QTimer::stop);
 
     m_connectTimer.setInterval(10000);
     m_connectTimer.setSingleShot(true);
 
-    QTimer::singleShot(0, this, SLOT(start()));
+    QTimer::singleShot(0, this, &Mounter::start);
     qCDebug(KDECONNECT_PLUGIN_SFTP) << "Created mounter";
 }
 
@@ -68,14 +68,14 @@ bool Mounter::wait()
     qCDebug(KDECONNECT_PLUGIN_SFTP) << "Starting loop to wait for mount";
     
     MountLoop loop;
-    connect(this, SIGNAL(mounted()), &loop, SLOT(successed()));
-    connect(this, SIGNAL(failed(QString)), &loop, SLOT(failed()));
+    connect(this, &Mounter::mounted, &loop, &MountLoop::successed);
+    connect(this, &Mounter::failed, &loop, &MountLoop::failed);
     return loop.exec();
 }
 
 void Mounter::onPakcageReceived(const NetworkPackage& np)
 {
-    if (np.get<bool>("stop", false))
+    if (np.get<bool>(QStringLiteral("stop"), false))
     {
         qCDebug(KDECONNECT_PLUGIN_SFTP) << "SFTP server stopped";
         unmount();
@@ -101,40 +101,41 @@ void Mounter::onPakcageReceived(const NetworkPackage& np)
     m_proc = new KProcess(this);
     m_proc->setOutputChannelMode(KProcess::MergedChannels);
 
-    connect(m_proc, SIGNAL(started()), SLOT(onStarted()));
+    connect(m_proc, &QProcess::started, this, &Mounter::onStarted);
     connect(m_proc, SIGNAL(error(QProcess::ProcessError)), SLOT(onError(QProcess::ProcessError)));
     connect(m_proc, SIGNAL(finished(int,QProcess::ExitStatus)), SLOT(onFinished(int,QProcess::ExitStatus)));
 
     QDir().mkpath(m_mountPoint);
 
-    const QString program = "sshfs";
+    const QString program = QStringLiteral("sshfs");
 
     QString path;
-    if (np.has("multiPaths")) path = '/';
-    else path = np.get<QString>("path");
+    if (np.has(QStringLiteral("multiPaths"))) path = '/';
+    else path = np.get<QString>(QStringLiteral("path"));
 
     const QStringList arguments = QStringList()
-        << QString("%1@%2:%3")
-            .arg(np.get<QString>("user"))
-            .arg(np.get<QString>("ip"))
-            .arg(path)
+        << QStringLiteral("%1@%2:%3").arg(
+            np.get<QString>(QStringLiteral("user")),
+            np.get<QString>(QStringLiteral("ip")),
+            path)
         << m_mountPoint
-        << "-p" << np.get<QString>("port")
-        << "-f"
-        << "-o" << "IdentityFile=" + KdeConnectConfig::instance()->privateKeyPath()
-        << "-o" << "StrictHostKeyChecking=no" //Do not ask for confirmation because it is not a known host
-        << "-o" << "UserKnownHostsFile=/dev/null" //Prevent storing as a known host
-        << "-o" << "HostKeyAlgorithms=ssh-dss" //https://bugs.kde.org/show_bug.cgi?id=351725
-        << "-o" << "password_stdin"
+        << QStringLiteral("-p") << np.get<QString>(QStringLiteral("port"))
+        << QStringLiteral("-f")
+        << QStringLiteral("-F") << QStringLiteral("/dev/null") //Do not use ~/.ssh/config
+        << QStringLiteral("-o") << "IdentityFile=" + KdeConnectConfig::instance()->privateKeyPath()
+        << QStringLiteral("-o") << QStringLiteral("StrictHostKeyChecking=no") //Do not ask for confirmation because it is not a known host
+        << QStringLiteral("-o") << QStringLiteral("UserKnownHostsFile=/dev/null") //Prevent storing as a known host
+        << QStringLiteral("-o") << QStringLiteral("HostKeyAlgorithms=ssh-dss") //https://bugs.kde.org/show_bug.cgi?id=351725
+        << QStringLiteral("-o") << QStringLiteral("password_stdin")
         ;
 
     m_proc->setProgram(program, arguments);
 
-    qCDebug(KDECONNECT_PLUGIN_SFTP) << "Starting process: " << m_proc->program().join(" ");
+    qCDebug(KDECONNECT_PLUGIN_SFTP) << "Starting process: " << m_proc->program().join(QStringLiteral(" "));
     m_proc->start();
 
     //qCDebug(KDECONNECT_PLUGIN_SFTP) << "Passing password: " << np.get<QString>("password").toLatin1();
-    m_proc->write(np.get<QString>("password").toLatin1());
+    m_proc->write(np.get<QString>(QStringLiteral("password")).toLatin1());
     m_proc->write("\n");
 
 }
@@ -205,7 +206,7 @@ void Mounter::unmount()
         toDestroy->kill();
         delete toDestroy;
         //Free mount point (won't always succeed if the path is in use)
-        KProcess::execute(QStringList() << "fusermount" << "-u" << m_mountPoint, 10000);
+        KProcess::execute(QStringList() << QStringLiteral("fusermount") << QStringLiteral("-u") << m_mountPoint, 10000);
     }
     m_started = false;
 }
