@@ -22,8 +22,10 @@
 #include <QApplication>
 #include <QNetworkAccessManager>
 #include <QTest>
-#include <QTemporaryFile>
+#include <QBuffer>
 #include <QStandardPaths>
+#include <QImage>
+#include <QColor>
 
 #include <kiconloader.h>
 
@@ -85,17 +87,23 @@ public:
         return sentPackages;
     }
 
-    const NetworkPackage* getLastPackage() const
+    NetworkPackage* getLastPackage()
     {
         return lastPackage;
     }
 
+    void deleteLastPackage()
+    {
+        delete lastPackage;
+        lastPackage = nullptr;
+    }
+
 public Q_SLOTS:
     bool sendPackage(NetworkPackage& np) override
     {
         ++sentPackages;
         // copy package manually to allow for inspection (can't use copy-constructor)
-        delete lastPackage;
+        deleteLastPackage();
         lastPackage = new NetworkPackage(np.type());
         Q_ASSERT(lastPackage);
         for (QVariantMap::ConstIterator iter = np.body().constBegin();
@@ -109,7 +117,7 @@ public Q_SLOTS:
 // Tweaked NotificationsListener for testing:
 class TestedNotificationsListener: public NotificationsListener
 {
-
+    Q_OBJECT
 public:
     explicit TestedNotificationsListener(KdeConnectPlugin* aPlugin)
         : NotificationsListener(aPlugin)
@@ -128,6 +136,22 @@ public:
         applications = value;
     }
 
+protected:
+    bool parseImageDataArgument(const QVariant& argument, int& width,
+                                int& height, int& rowStride, int& bitsPerSample,
+                                int& channels, bool& hasAlpha,
+                                QByteArray& imageData) const override
+    {
+        width = argument.toMap().value(QStringLiteral("width")).toInt();
+        height = argument.toMap().value(QStringLiteral("height")).toInt();
+        rowStride = argument.toMap().value(QStringLiteral("rowStride")).toInt();
+        bitsPerSample = argument.toMap().value(QStringLiteral("bitsPerSample")).toInt();
+        channels = argument.toMap().value(QStringLiteral("channels")).toInt();
+        hasAlpha = argument.toMap().value(QStringLiteral("hasAlpha")).toBool();
+        imageData = argument.toMap().value(QStringLiteral("imageData")).toByteArray();
+        return true;
+    }
+
 };
 
 class TestNotificationListener : public QObject
@@ -153,7 +177,7 @@ void TestNotificationListener::testNotify()
     // set things up:
     //
 
-    QString dId("testid");
+    QString dId(QStringLiteral("testid"));
     TestDevice *d = new TestDevice(nullptr, dId);
 
     int proxiedNotifications = 0;
@@ -172,9 +196,9 @@ void TestNotificationListener::testNotify()
     QCOMPARE(listener, plugin->getNotificationsListener());
 
     // make sure config is default:
-    plugin->config()->set("generalPersistent", false);
-    plugin->config()->set("generalIncludeBody", true);
-    plugin->config()->set("generalUrgency", 0);
+    plugin->config()->set(QStringLiteral("generalPersistent"), false);
+    plugin->config()->set(QStringLiteral("generalIncludeBody"), true);
+    plugin->config()->set(QStringLiteral("generalUrgency"), 0);
     QCOMPARE(plugin->config()->get<bool>("generalPersistent"), false);
     QCOMPARE(plugin->config()->get<bool>("generalIncludeBody"), true);
     QCOMPARE(plugin->config()->get<bool>("generalUrgency"), false);
@@ -189,10 +213,10 @@ void TestNotificationListener::testNotify()
 
     uint replacesId = 99;
     uint retId;
-    QString appName("some-appName");
-    QString body("some-body");
-    QString icon("some-icon");
-    QString summary("some-summary");
+    QString appName(QStringLiteral("some-appName"));
+    QString body(QStringLiteral("some-body"));
+    QString icon(QStringLiteral("some-icon"));
+    QString summary(QStringLiteral("some-summary"));
 
     // regular Notify call that is synchronized ...
     retId = listener->Notify(appName, replacesId, icon, summary, body, {}, {{}}, 0);
@@ -217,10 +241,10 @@ void TestNotificationListener::testNotify()
     QCOMPARE(listener->getApplications()[appName].icon, icon);
 
     // another one, with other timeout and urgency values:
-    QString appName2("some-appName2");
-    QString body2("some-body2");
-    QString icon2("some-icon2");
-    QString summary2("some-summary2");
+    QString appName2(QStringLiteral("some-appName2"));
+    QString body2(QStringLiteral("some-body2"));
+    QString icon2(QStringLiteral("some-icon2"));
+    QString summary2(QStringLiteral("some-summary2"));
 
     retId = listener->Notify(appName2, replacesId+1, icon2, summary2, body2, {}, {{"urgency", 2}}, 10);
     QCOMPARE(retId, replacesId+1);
@@ -235,7 +259,7 @@ void TestNotificationListener::testNotify()
     QVERIFY(listener->getApplications().contains(appName));
 
     // if persistent-only is set, timeouts > 0 are not synced:
-    plugin->config()->set("generalPersistent", true);
+    plugin->config()->set(QStringLiteral("generalPersistent"), true);
     retId = listener->Notify(appName, replacesId, icon, summary, body, {}, {{}}, 1);
     QCOMPARE(retId, 0U);
     QCOMPARE(proxiedNotifications, d->getSentPackages());
@@ -246,10 +270,10 @@ void TestNotificationListener::testNotify()
     retId = listener->Notify(appName, replacesId, icon, summary, body, {}, {{}}, 0);
     QCOMPARE(retId, replacesId);
     QCOMPARE(++proxiedNotifications, d->getSentPackages());
-    plugin->config()->set("generalPersistent", false);
+    plugin->config()->set(QStringLiteral("generalPersistent"), false);
 
     // if min-urgency is set, lower urgency levels are not synced:
-    plugin->config()->set("generalUrgency", 1);
+    plugin->config()->set(QStringLiteral("generalUrgency"), 1);
     retId = listener->Notify(appName, replacesId, icon, summary, body, {}, {{"urgency", 0}}, 0);
     QCOMPARE(retId, 0U);
     QCOMPARE(proxiedNotifications, d->getSentPackages());
@@ -261,7 +285,7 @@ void TestNotificationListener::testNotify()
     retId = listener->Notify(appName, replacesId, icon, summary, body, {}, {{"urgency", 2}}, 0);
     QCOMPARE(retId, replacesId);
     QCOMPARE(++proxiedNotifications, d->getSentPackages());
-    plugin->config()->set("generalUrgency", 0);
+    plugin->config()->set(QStringLiteral("generalUrgency"), 0);
 
     // notifications for a deactivated application are not synced:
     QVERIFY(listener->getApplications().contains(appName));
@@ -283,42 +307,42 @@ void TestNotificationListener::testNotify()
 
     // notifications with blacklisted subjects are not synced:
     QVERIFY(listener->getApplications().contains(appName));
-    listener->getApplications()[appName].blacklistExpression.setPattern("black[12]|foo(bar|baz)");
-    retId = listener->Notify(appName, replacesId, icon, "summary black1", body, {}, {{}}, 0);
+    listener->getApplications()[appName].blacklistExpression.setPattern(QStringLiteral("black[12]|foo(bar|baz)"));
+    retId = listener->Notify(appName, replacesId, icon, QStringLiteral("summary black1"), body, {}, {{}}, 0);
     QCOMPARE(retId, 0U);
     QCOMPARE(proxiedNotifications, d->getSentPackages());
-    retId = listener->Notify(appName, replacesId, icon, "summary foobar", body, {}, {{}}, 0);
+    retId = listener->Notify(appName, replacesId, icon, QStringLiteral("summary foobar"), body, {}, {{}}, 0);
     QCOMPARE(retId, 0U);
     QCOMPARE(proxiedNotifications, d->getSentPackages());
     // other subjects are synced:
-    retId = listener->Notify(appName, replacesId, icon, "summary foo", body, {}, {{}}, 0);
+    retId = listener->Notify(appName, replacesId, icon, QStringLiteral("summary foo"), body, {}, {{}}, 0);
     QCOMPARE(retId, replacesId);
     QCOMPARE(++proxiedNotifications, d->getSentPackages());
-    retId = listener->Notify(appName, replacesId, icon, "summary black3", body, {}, {{}}, 0);
+    retId = listener->Notify(appName, replacesId, icon, QStringLiteral("summary black3"), body, {}, {{}}, 0);
     QCOMPARE(retId, replacesId);
     QCOMPARE(++proxiedNotifications, d->getSentPackages());
     // also body is checked by blacklist if requested:
-    plugin->config()->set("generalIncludeBody", true);
-    retId = listener->Notify(appName, replacesId, icon, summary, "body black1", {}, {{}}, 0);
+    plugin->config()->set(QStringLiteral("generalIncludeBody"), true);
+    retId = listener->Notify(appName, replacesId, icon, summary, QStringLiteral("body black1"), {}, {{}}, 0);
     QCOMPARE(retId, 0U);
     QCOMPARE(proxiedNotifications, d->getSentPackages());
-    retId = listener->Notify(appName, replacesId, icon, summary, "body foobaz", {}, {{}}, 0);
+    retId = listener->Notify(appName, replacesId, icon, summary, QStringLiteral("body foobaz"), {}, {{}}, 0);
     QCOMPARE(retId, 0U);
     QCOMPARE(proxiedNotifications, d->getSentPackages());
     // body does not matter if inclusion was not requested:
-    plugin->config()->set("generalIncludeBody", false);
-    retId = listener->Notify(appName, replacesId, icon, summary, "body black1", {}, {{}}, 0);
+    plugin->config()->set(QStringLiteral("generalIncludeBody"), false);
+    retId = listener->Notify(appName, replacesId, icon, summary, QStringLiteral("body black1"), {}, {{}}, 0);
     QCOMPARE(retId, replacesId);
     QCOMPARE(++proxiedNotifications, d->getSentPackages());
     // without body, also ticker value is different:
     QCOMPARE(d->getLastPackage()->get<QString>("ticker"), summary);
-    retId = listener->Notify(appName, replacesId, icon, summary, "body foobaz", {}, {{}}, 0);
+    retId = listener->Notify(appName, replacesId, icon, summary, QStringLiteral("body foobaz"), {}, {{}}, 0);
     QCOMPARE(retId, replacesId);
     QCOMPARE(++proxiedNotifications, d->getSentPackages());
 
     // back to normal:
-    listener->getApplications()[appName].blacklistExpression.setPattern("");
-    plugin->config()->set("generalIncludeBody", true);
+    listener->getApplications()[appName].blacklistExpression.setPattern(QLatin1String(""));
+    plugin->config()->set(QStringLiteral("generalIncludeBody"), true);
     retId = listener->Notify(appName, replacesId, icon, summary, body, {}, {{}}, 0);
     QCOMPARE(retId, replacesId);
     QCOMPARE(++proxiedNotifications, d->getSentPackages());
@@ -327,31 +351,148 @@ void TestNotificationListener::testNotify()
     QCOMPARE(++proxiedNotifications, d->getSentPackages());
 
     // icon synchronization:
+    QStringList iconPaths;
+    // appIcon
     int count = 0;
     Q_FOREACH (const auto& iconName, KIconLoader::global()->queryIcons(-KIconLoader::SizeEnormous, KIconLoader::Application)) {
-        if (!iconName.endsWith(".png"))
+        if (!iconName.endsWith(QLatin1String(".png")))
             continue;
         if (count++ > 3) // max 3 iterations
             break;
+        iconPaths.append(iconName); // memorize some paths for later
 
         // existing icons are sync-ed if requested
-        plugin->config()->set("generalSynchronizeIcons", true);
+        plugin->config()->set(QStringLiteral("generalSynchronizeIcons"), true);
         QFileInfo fi(iconName);
-        //qDebug() << "XXX" << iconName << fi.baseName() << fi.size();
         retId = listener->Notify(appName, replacesId, fi.baseName(), summary, body, {}, {{}}, 0);
         QCOMPARE(retId, replacesId);
         QCOMPARE(++proxiedNotifications, d->getSentPackages());
         QVERIFY(d->getLastPackage()->hasPayload());
         QCOMPARE(d->getLastPackage()->payloadSize(), fi.size());
+        // works also with abolute paths
+        retId = listener->Notify(appName, replacesId, iconName, summary, body, {}, {{}}, 0);
+        QCOMPARE(retId, replacesId);
+        QCOMPARE(++proxiedNotifications, d->getSentPackages());
+        QVERIFY(d->getLastPackage()->hasPayload());
+        QCOMPARE(d->getLastPackage()->payloadSize(), fi.size());
+        // extensions other than png are not accepted:
+        retId = listener->Notify(appName, replacesId, iconName + ".svg", summary, body, {}, {{}}, 0);
+        QCOMPARE(retId, replacesId);
+        QCOMPARE(++proxiedNotifications, d->getSentPackages());
+        QVERIFY(!d->getLastPackage()->hasPayload());
 
-        // otherwise no payload:
-        plugin->config()->set("generalSynchronizeIcons", false);
+        // if sync not requested no payload:
+        plugin->config()->set(QStringLiteral("generalSynchronizeIcons"), false);
         retId = listener->Notify(appName, replacesId, fi.baseName(), summary, body, {}, {{}}, 0);
         QCOMPARE(retId, replacesId);
         QCOMPARE(++proxiedNotifications, d->getSentPackages());
         QVERIFY(!d->getLastPackage()->hasPayload());
         QCOMPARE(d->getLastPackage()->payloadSize(), 0);
     }
+    plugin->config()->set(QStringLiteral("generalSynchronizeIcons"), true);
+
+    // image-path in hints
+    if (iconPaths.size() > 0) {
+        retId = listener->Notify(appName, replacesId, iconPaths.size() > 1 ? iconPaths[1] : icon, summary, body, {}, {{"image-path", iconPaths[0]}}, 0);
+        QCOMPARE(retId, replacesId);
+        QCOMPARE(++proxiedNotifications, d->getSentPackages());
+        QVERIFY(d->getLastPackage()->hasPayload());
+        QFileInfo hintsFi(iconPaths[0]);
+        // image-path has priority over appIcon parameter:
+        QCOMPARE(d->getLastPackage()->payloadSize(), hintsFi.size());
+    }
+
+    // image_path in hints
+    if (iconPaths.size() > 0) {
+        retId = listener->Notify(appName, replacesId, iconPaths.size() > 1 ? iconPaths[1] : icon, summary, body, {}, {{"image_path", iconPaths[0]}}, 0);
+        QCOMPARE(retId, replacesId);
+        QCOMPARE(++proxiedNotifications, d->getSentPackages());
+        QVERIFY(d->getLastPackage()->hasPayload());
+        QFileInfo hintsFi(iconPaths[0]);
+        // image_path has priority over appIcon parameter:
+        QCOMPARE(d->getLastPackage()->payloadSize(), hintsFi.size());
+    }
+
+    // image-data in hints
+    // set up:
+    QBuffer *buffer;
+    QImage image;
+    int width = 2, height = 2, rowStride = 4*width, bitsPerSample = 8,
+            channels = 4;
+    bool hasAlpha = 1;
+    char rawData[] = { 0x01, 0x02, 0x03, 0x04,  // raw rgba data
+                       0x11, 0x12, 0x13, 0x14,
+                       0x21, 0x22, 0x23, 0x24,
+                       0x31, 0x32, 0x33, 0x34 };
+    QVariantMap imageData = {{"width", width}, {"height", height}, {"rowStride", rowStride},
+                            {"bitsPerSample", bitsPerSample}, {"channels", channels},
+                            {"hasAlpha", hasAlpha}, {"imageData", rawData}};
+    QVariantMap hints;
+#define COMPARE_PIXEL(x, y) \
+    QCOMPARE(qRed(image.pixel(x,y)), (int)rawData[x*4 + y*rowStride + 0]); \
+    QCOMPARE(qGreen(image.pixel(x,y)), (int)rawData[x*4 + y*rowStride + 1]); \
+    QCOMPARE(qBlue(image.pixel(x,y)), (int)rawData[x*4 + y*rowStride + 2]); \
+    QCOMPARE(qAlpha(image.pixel(x,y)), (int)rawData[x*4 + y*rowStride + 3]);
+
+    hints.insert(QStringLiteral("image-data"), imageData);
+    if (iconPaths.size() > 0)
+        hints.insert(QStringLiteral("image-path"), iconPaths[0]);
+    retId = listener->Notify(appName, replacesId, icon, summary, body, {}, hints, 0);
+    QCOMPARE(retId, replacesId);
+    QCOMPARE(++proxiedNotifications, d->getSentPackages());
+    QVERIFY(d->getLastPackage()->hasPayload());
+    buffer = dynamic_cast<QBuffer*>(d->getLastPackage()->payload().data());
+    QCOMPARE(d->getLastPackage()->payloadSize(), buffer->size());
+    // image-data is attached as png data
+    QVERIFY(image.loadFromData(reinterpret_cast<const uchar*>(buffer->data().constData()), buffer->size(), "PNG"));
+    // image-data has priority over image-path:
+    QCOMPARE(image.byteCount(), rowStride*height);
+    // rgba -> argb conversion was done correctly:
+    COMPARE_PIXEL(0,0);
+    COMPARE_PIXEL(1,0);
+    COMPARE_PIXEL(0,1);
+    COMPARE_PIXEL(1,1);
+
+    // same for image_data in hints
+    hints.clear();
+    hints.insert(QStringLiteral("image-data"), imageData);
+    if (iconPaths.size() > 0)
+        hints.insert(QStringLiteral("image_path"), iconPaths[0]);
+    retId = listener->Notify(appName, replacesId, icon, summary, body, {}, hints, 0);
+    QCOMPARE(retId, replacesId);
+    QCOMPARE(++proxiedNotifications, d->getSentPackages());
+    QVERIFY(d->getLastPackage()->hasPayload());
+    buffer = dynamic_cast<QBuffer*>(d->getLastPackage()->payload().data());
+    QCOMPARE(d->getLastPackage()->payloadSize(), buffer->size());
+    // image-data is attached as png data
+    QVERIFY(image.loadFromData(reinterpret_cast<const uchar*>(buffer->data().constData()), buffer->size(), "PNG"));
+    // image_data has priority over image_path/image-path:
+    QCOMPARE(image.byteCount(), rowStride*height);
+    // rgba -> argb conversion was done correctly:
+    COMPARE_PIXEL(0,0);
+    COMPARE_PIXEL(1,0);
+    COMPARE_PIXEL(0,1);
+    COMPARE_PIXEL(1,1);
+
+    // same for icon_data, which has lowest priority
+    hints.clear();
+    hints.insert(QStringLiteral("icon_data"), imageData);
+    retId = listener->Notify(appName, replacesId, QLatin1String(""), summary, body, {}, hints, 0);
+    QCOMPARE(retId, replacesId);
+    QCOMPARE(++proxiedNotifications, d->getSentPackages());
+    QVERIFY(d->getLastPackage());
+    QVERIFY(d->getLastPackage()->hasPayload());
+    buffer = dynamic_cast<QBuffer*>(d->getLastPackage()->payload().data());
+    // image-data is attached as png data
+    QVERIFY(image.loadFromData(reinterpret_cast<const uchar*>(buffer->data().constData()), buffer->size(), "PNG"));
+    QCOMPARE(image.byteCount(), rowStride*height);
+    // rgba -> argb conversion was done correctly:
+    COMPARE_PIXEL(0,0);
+    COMPARE_PIXEL(1,0);
+    COMPARE_PIXEL(0,1);
+    COMPARE_PIXEL(1,1);
+
+#undef COMPARE_PIXEL
 }
 
 
